go2ts

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 7, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package go2ts provides core conversion from Go structs to TypeScript definitions.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Convert

func Convert(inputDir, outputFile string) error

Convert - converts Go structs in the input directory to TypeScript types in the output file.

Types

This section is empty.

Jump to